(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     26040,        694]
NotebookOptionsPosition[     25451,        669]
NotebookOutlinePosition[     25811,        685]
CellTagsIndexPosition[     25768,        682]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "Functions", " ", "for", " ", "Constructing", " ", "the", " ", "C", " ", 
     RowBox[{"Term", " ", "[", 
      RowBox[{"via", " ", "chains"}], "]"}]}], " ", "*)"}],
   FontSize->18], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Functions", " ", "for", " ", "applying", " ", "symmetric", " ", 
    "differences", " ", "to", " ", "collections", " ", "of", " ", "subsets"}],
    " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Alters", " ", "a", " ", "list", " ", "of", " ", "sets", " ", "by", " ", 
    "applying", " ", "the", " ", "symmetric", " ", "difference", " ", "with", 
    " ", "a", " ", "specified", " ", "set", " ", "J"}], "\[IndentingNewLine]",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"JSymDif", "[", 
      RowBox[{"J_", ",", "A_"}], "]"}], ":=", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"SymmetricDifference", "[", 
         RowBox[{"#", ",", "J"}], "]"}], "&"}], ",", "A"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Writes", " ", "out", " ", "the", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Phi]", "A"], "+", 
        SubscriptBox["\[Phi]", 
         SuperscriptBox["A", "c"]]}], ")"}], " ", "product", " ", 
      "corresponding", " ", "to", " ", "a", " ", "list", " ", "of", " ", 
      "subsets", " ", "\[IndentingNewLine]", "A"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["A", "1"], ",", "...", ",", 
       SubscriptBox["A", "k"]}], "}"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"ProdTerm", "[", 
      RowBox[{"A_", ",", "set_"}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{
        RowBox[{"Length", "[", "set", "]"}], "-", 
        RowBox[{"Length", "[", "A", "]"}]}]], 
      RowBox[{"ProductOver", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]", "[", "#", "]"}], "+", 
          RowBox[{"\[Phi]", "[", 
           RowBox[{"Complement", "[", 
            RowBox[{"set", ",", "#"}], "]"}], "]"}]}], "&"}], ",", "A"}], 
       "]"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Gives", " ", "the", " ", "sum", " ", "over", " ", "all", " ", "chains", 
      " ", "with", " ", 
      SubscriptBox["A", "1"]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"{", "1", "}"}], " ", "and", " ", "all", " ", "subsets", " ", 
       "J"}], " ", "\[Subset]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"2", ".."}], "n"}], "}"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CTermSum", "[", "n_", "]"}], ":=", 
     RowBox[{"SumOver", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ProdTerm", "[", 
         RowBox[{
          RowBox[{"JSymDif", "@@", "#"}], ",", 
          RowBox[{"Range", "[", "n", "]"}]}], "]"}], "&"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Tuples", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Subsets", "[", 
           RowBox[{"Range", "[", 
            RowBox[{"2", ",", "n"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Chains", "[", 
           RowBox[{
            RowBox[{"Range", "[", "n", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"{", "1", "}"}], "}"}], ",", "True"}], "]"}]}], 
         "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Gives", " ", "the", " ", "E", " ", "sum"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ETermSum", "[", "n_", "]"}], ":=", 
     RowBox[{"SumOver", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "+", "1"}]], 
         RowBox[{"\[Phi]", "[", "#", "]"}]}], "&"}], ",", 
       RowBox[{"Subsets", "[", 
        RowBox[{"Range", "[", "n", "]"}], "]"}]}], "]"}]}], 
    ";"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.548434124412774*^9, 3.5484341638858337`*^9}, {
   3.548434475323036*^9, 3.548434477946494*^9}, 3.54843553510063*^9, {
   3.54869946666714*^9, 3.54869954612924*^9}, {3.548699619589835*^9, 
   3.548699666825502*^9}, {3.548781116758748*^9, 3.548781117865799*^9}, {
   3.548781165925847*^9, 3.5487812772896423`*^9}, {3.548781396467039*^9, 
   3.548781543481414*^9}, {3.548781646516526*^9, 3.548781647711051*^9}, {
   3.548781694369151*^9, 3.548781958954865*^9}, {3.548782374812982*^9, 
   3.548782452204612*^9}, {3.5487860156244717`*^9, 3.548786086730506*^9}, {
   3.549818848492015*^9, 3.549818849401411*^9}, {3.550091218174741*^9, 
   3.550091244177066*^9}, {3.550124949550201*^9, 3.5501252196950197`*^9}, {
   3.550125574788478*^9, 3.550125588257471*^9}, {3.550251743565184*^9, 
   3.550251747778998*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "Functions", " ", "for", " ", "Simplifying", " ", "the", " ", "C", " ", 
     RowBox[{"Term", " ", "[", 
      RowBox[{"via", " ", "chains"}], "]"}]}], " ", "*)"}],
   FontSize->18], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Keeps", " ", "only", " ", "the", " ", "minimal", " ", "elements", " ", 
    "in", " ", "a", " ", "product", " ", "of", " ", "\[Phi]", " ", "terms"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Minimal\[Phi]Terms", "[", "exp_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "res", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Collect", " ", "products", " ", "of", " ", 
         RowBox[{"\[Phi]", "'"}], "s", " ", "together", " ", "and", " ", 
         "apply", " ", "the", " ", "\"\<minimal elements\>\"", " ", 
         "filter"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"res", "=", 
         RowBox[{
          RowBox[{"Expand", "[", "exp", "]"}], "//.", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Phi]", "[", "x__", "]"}], 
            RowBox[{"\[Phi]", "[", "y__", "]"}]}], "\[RuleDelayed]", 
           RowBox[{"\[Phi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"res", "=", 
         RowBox[{"res", "/.", 
          RowBox[{
           RowBox[{"\[Phi]", "[", "x__", "]"}], "\[RuleDelayed]", 
           RowBox[{"\[Phi]", "@@", 
            RowBox[{"Sort", "[", 
             RowBox[{"MinimalElements", "[", 
              RowBox[{
               RowBox[{"{", "x", "}"}], ",", "IsSubset"}], "]"}], 
             "]"}]}]}]}]}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "Tests", " ", "a", " ", "given", " ", "product", " ", "of", " ", 
      RowBox[{"\[Phi]", "'"}], "s", " ", "to", " ", "see", " ", "if", " ", 
      "the", " ", "factors", " ", "satisfy", " ", "the", " ", "inequality", 
      " ", "in", " ", "Lemma", " ", "4.4", " ", "such", " ", "as", " ", 
      "being", " ", 
      RowBox[{"disjoint", "."}]}], " ", ";", " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "Checks", " ", "all", " ", "possible", " ", "subsets", " ", "of", " ", 
        "the", " ", "factors"}], ")"}], "."}]}], "\[IndentingNewLine]", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ThrowAwayZeros", "[", "exp_", "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"exp", "/.", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "x__", "]"}], "\[RuleDelayed]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Or", "@@", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Test\[Phi]Zero", "[", "#", "]"}], "&"}], ",", 
            RowBox[{"Subsets", "[", 
             RowBox[{"{", "x", "}"}], "]"}]}], "]"}]}], ",", "0", ",", 
         RowBox[{"\[Phi]", "[", "x", "]"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Tests", " ", "if", " ", "the", " ", "list", " ", "of", " ", "subsets", 
      " ", "A"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["A", "1"], ",", "...", ",", 
        SubscriptBox["A", "k"]}], "}"}], " ", "satisfies", " ", "the", " ", 
      "inequality", " ", "in", " ", "Lemma", " ", "4.4", " ", "by", " ", 
      "adding", " ", "up", " ", "the", " ", "rows", " ", "of", " ", "the", 
      " ", "ContainmentsMatrix"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Test\[Phi]Zero", "[", "A_", "]"}], ":=", "\[IndentingNewLine]", 
     
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "A", "]"}], "\[LessEqual]", "1"}], ",", 
       "False", ",", "\[IndentingNewLine]", 
       RowBox[{"And", "@@", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Total", "[", "#", "]"}], "\[LessEqual]", 
            RowBox[{
             FractionBox["3", "4"], 
             RowBox[{"Length", "[", "A", "]"}]}]}], "&"}], ",", 
          RowBox[{"ContainmentsMatrix", "[", "A", "]"}]}], "]"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Generates", " ", "a", " ", "matrix", " ", "whose", " ", "ij"}],
       "-", 
      RowBox[{"th", " ", "entry", " ", "is"}]}], ",", " ", "respectively", 
     ",", " ", 
     RowBox[{
      RowBox[{"1", " ", 
       RowBox[{"(", "0", ")"}], " ", "if", " ", 
       RowBox[{"elem", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], " ", "\[Element]", " ", 
      RowBox[{
       RowBox[{"(", "\[NotElement]", ")"}], " ", 
       RowBox[{
        RowBox[{"set", "[", 
         RowBox[{"[", "j", "]"}], "]"}], "."}]}]}]}], "\[IndentingNewLine]", 
    "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ContainmentsMatrix", "[", "sets_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "elems", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"elems", "=", 
         RowBox[{"Union", "@@", "sets"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Outer", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Boole", "[", 
            RowBox[{"MemberQ", "[", 
             RowBox[{"#2", ",", "#1"}], "]"}], "]"}], "&"}], ",", 
          "\[IndentingNewLine]", "elems", ",", "\[IndentingNewLine]", "sets", 
          ",", "\[IndentingNewLine]", "1"}], "\[IndentingNewLine]", "]"}]}]}],
       "\[IndentingNewLine]", "]"}]}], ";"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5484651369764442`*^9, 3.548465159519858*^9}, {
   3.548465905585987*^9, 3.5484659092749243`*^9}, {3.548466342962812*^9, 
   3.548466343818343*^9}, {3.548466380843663*^9, 3.548466381179427*^9}, {
   3.548781991959701*^9, 3.548781993421232*^9}, {3.548782613216909*^9, 
   3.548782760857594*^9}, {3.548782814988883*^9, 3.5487828778651342`*^9}, {
   3.548783062294009*^9, 3.548783116645047*^9}, {3.548783477227962*^9, 
   3.548783477849675*^9}, 3.548783556148692*^9, {3.5487852576686153`*^9, 
   3.5487852678009253`*^9}, {3.5487852994512863`*^9, 3.548785393558337*^9}, {
   3.548785504501512*^9, 3.5487855058201303`*^9}, {3.548785671139958*^9, 
   3.548785776757605*^9}, 3.5487859359940367`*^9, {3.548785969534708*^9, 
   3.5487859937372932`*^9}, {3.5487862275226183`*^9, 
   3.5487862332546253`*^9}, {3.548954122622994*^9, 3.548954124293892*^9}, {
   3.549833562402021*^9, 3.5498335848194304`*^9}, {3.5498558990259857`*^9, 
   3.5498559514922533`*^9}, {3.549856052603374*^9, 3.549856053947907*^9}, {
   3.549856101337641*^9, 3.549856116844308*^9}, {3.549856148739291*^9, 
   3.549856149488308*^9}, {3.550091433769828*^9, 3.550091446481386*^9}, {
   3.550092469699196*^9, 3.550092470577559*^9}, {3.550125362754046*^9, 
   3.550125510001874*^9}, {3.5501255461977997`*^9, 3.550125566117057*^9}, {
   3.550125878142002*^9, 3.550125900257345*^9}, {3.550251778077552*^9, 
   3.5502518203805933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Testing", " ", 
     RowBox[{"Area", "!"}]}], " ", "*)"}],
   FontSize->18], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "The", " ", "goal", " ", "is", " ", "to", " ", "find", " ", "out", " ", 
       "if", " ", 
       RowBox[{"CTermSum", "[", "n", "]"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ETermSum", "[", "n", "]"}], " ", "as", " ", "functions", 
           " ", "on", " ", 
           SubscriptBox[
            RowBox[{"(", 
             SuperscriptBox["R", "n"], ")"}], 
            RowBox[{"\[GreaterEqual]", "0"}]], " ", "in", " ", "the", " ", 
           "range", " ", 
           SubscriptBox["u", "1"]}], "+"}], "..."}], "+", 
        SubscriptBox["u", "n"]}], "<", "2."}]}], " ", ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
     "We", " ", "do", " ", "this", " ", "by", " ", "writing", " ", "out", " ",
       "the", " ", "sums", " ", "and", " ", "simplifying", " ", "them", " ", 
      "according", " ", "to", " ", "Lemma", " ", 
      RowBox[{"4.4", "."}]}], " ", ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Note", " ", "that", " ", 
      RowBox[{"I", "'"}], "m", " ", "using", " ", "\[Phi]", " ", "instead", 
      " ", "of", " ", 
      OverscriptBox["\[Chi]", "~"], " ", "for", " ", "the", " ", "indicator", 
      " ", "function", " ", "of", " ", 
      RowBox[{"(", 
       RowBox[{"1", ",", "\[Infinity]"}], ")"}]}]}], ",", " ", 
    RowBox[{"and", " ", "note", " ", "that", " ", 
     RowBox[{"\[Phi]", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "5"}], "}"}], "]"}], " ", "means", " ", 
     RowBox[{"\[Phi]", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", "1"], "+", 
        SubscriptBox["u", "2"], "-", 
        SubscriptBox["u", "3"], "-", 
        SubscriptBox["u", "4"], "+", 
        SubscriptBox["u", "5"], "-"}], "..."}], "]"}], " ", "and", " ", "so", 
     " ", 
     RowBox[{"on", ".", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"The", " ", "set", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "5"}], "}"}], " ", "represents", " ", 
         "the"}], " ", "+", " ", 
        RowBox[{"signs", "."}]}], ")"}]}], " ", "Thus", " ", 
     RowBox[{"\[Phi]", "[", 
      RowBox[{"{", "}"}], "]"}], " ", "is", " ", "actually", " ", 
     "identically", " ", "0", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "but", " ", "still", " ", "shows", " ", "up", " ", "because", " ", 
        RowBox[{"it", "'"}], "s", " ", "notationally", " ", "convenient"}], 
       ")"}], "."}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "*)"}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Be", " ", 
    RowBox[{"forewarned", ":", " ", 
     RowBox[{
      RowBox[{"this", " ", "is", " ", "slow", " ", "when", " ", "n"}], " ", 
      ">", " ", 
      RowBox[{
      "5", " ", "and", " ", "extremely", " ", "slow", " ", "when", " ", "n"}],
       " ", "\[GreaterEqual]", " ", 
      RowBox[{"7", " ", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", "=", "6"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"expr", "=", 
     RowBox[{"CTermSum", "[", "n", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"expr", "=", 
     RowBox[{"Minimal\[Phi]Terms", "[", "expr", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"expr", "=", 
    RowBox[{"ThrowAwayZeros", "[", "expr", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.548786117267866*^9, 3.5487861401423492`*^9}, {
  3.548786270863859*^9, 3.548786413872649*^9}, {3.5487866160929127`*^9, 
  3.5487866360993834`*^9}, {3.5487936636710777`*^9, 3.54879366378938*^9}, {
  3.548795005836841*^9, 3.548795300700959*^9}, {3.5498561402296677`*^9, 
  3.549856140364605*^9}, {3.550125800578039*^9, 3.55012583216405*^9}, {
  3.550125927666444*^9, 3.5501259316413803`*^9}, {3.550251853465201*^9, 
  3.550251857461372*^9}, {3.550251888283369*^9, 3.550251902128316*^9}, {
  3.552933329642332*^9, 3.552933334112661*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4683", " ", 
   RowBox[{"\[Phi]", "[", 
    RowBox[{"{", "}"}], "]"}]}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", "1", "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", "2", "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", "3", "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", "4", "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", "5", "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", "6", "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"4", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "4"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "5"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "4"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "5"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "4"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "5"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "5"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "5"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "4", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "4", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "5", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "4", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "4", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "5", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "4", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "5", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "5", ",", "6"}], "}"}], "]"}], "-", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "5", ",", "6"}], "}"}], "]"}], "+", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], "]"}], "+", 
  
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6"}], "}"}], "]"}], "+", 
  
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "5", ",", "6"}], "}"}], "]"}], "+", 
  
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "6"}], "}"}], "]"}], "+", 
  
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}], "]"}], "+", 
  
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}], "]"}], "-", 
  
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}], 
   "]"}]}]], "Output",
 CellChangeTimes->{{3.550125917908504*^9, 3.5501259614224043`*^9}, {
   3.55025188092432*^9, 3.550251897721116*^9}, 3.550252049727359*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "If", " ", "this", " ", "is", " ", "0", " ", "or", " ", "a", " ", 
     "multiple", " ", "of", " ", 
     RowBox[{"\[Phi]", "[", 
      RowBox[{"{", "}"}], "]"}]}], ",", 
    RowBox[{
    "you", " ", "have", " ", "proven", " ", "the", " ", "Fourier", " ", 
     "identity", " ", "for", " ", 
     RowBox[{"n", "."}]}]}], " ", "*)"}], 
  RowBox[{"exprC", "-", 
   RowBox[{"ETermSum", "[", "n", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.548786146686516*^9, 3.548786188005618*^9}, {
  3.54878624632743*^9, 3.548786246559038*^9}, {3.548786337110401*^9, 
  3.5487863412786837`*^9}, {3.550253813312307*^9, 3.55025382953262*^9}}],

Cell[BoxData[
 RowBox[{"4684", " ", 
  RowBox[{"\[Phi]", "[", 
   RowBox[{"{", "}"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.548786154089354*^9, 3.548786188387155*^9}, {
   3.548786247058964*^9, 3.5487862596724777`*^9}, {3.548786346439138*^9, 
   3.548786360920031*^9}, 3.548786611320444*^9, 3.548793669243882*^9, 
   3.549856156902608*^9, 3.5501257803242397`*^9, {3.55012591970621*^9, 
   3.550125932672893*^9}, {3.550251882240581*^9, 3.550251899648699*^9}, 
   3.550252615323454*^9}]
}, Open  ]]
},
WindowSize->{740, 576},
WindowMargins->{{28, Automatic}, {36, Automatic}},
ShowSelection->True,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 5318, 135, 378, "Input",
 InitializationCell->True],
Cell[5878, 157, 7385, 171, 606, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[13288, 332, 4271, 103, 329, "Input"],
Cell[17562, 437, 6647, 196, 178, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24246, 638, 698, 17, 43, "Input"],
Cell[24947, 657, 488, 9, 27, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
