(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     27632,        715]
NotebookOptionsPosition[     27253,        698]
NotebookOutlinePosition[     27590,        713]
CellTagsIndexPosition[     27547,        710]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Generally", " ", "Useful", " ", "Functions"}], " ", "*)"}],
   FontSize->18], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Functions", " ", "about", " ", "functions"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Compute", " ", "a", " ", "sum", " ", "or", " ", "product", " ", "of", 
     " ", "a", " ", "function", " ", "over", " ", "an", " ", "index", " ", 
     "set", "\[IndentingNewLine]", "Very", " ", "handy", " ", "for", " ", 
     "summing", " ", "over", " ", "partitions"}], ",", " ", "subsets", ",", 
    " ", 
    RowBox[{"etc", "..."}]}], " ", "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SumOver", "[", 
      RowBox[{"func_", ",", "set_"}], "]"}], ":=", 
     RowBox[{"Total", "@", 
      RowBox[{"Map", "[", 
       RowBox[{"func", ",", "set"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"ProductOver", "[", 
      RowBox[{"func_", ",", "set_"}], "]"}], ":=", 
     RowBox[{"Times", "@@", 
      RowBox[{"Map", "[", 
       RowBox[{"func", ",", "set"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Given", " ", "a", " ", "function", " ", "f", " ", "which", " ", 
      "returns", " ", "a", " ", "list", " ", "of", " ", "OUTPUTS"}], ",", " ", 
     RowBox[{
     "maps", " ", "f", " ", "over", " ", "a", " ", "list", " ", "of", " ", 
      "INPUTS", " ", "and", " ", "concatenates", " ", "all", " ", "the", " ", 
      "results"}]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ConcatMap", "[", 
      RowBox[{"f_", ",", "args_"}], "]"}], ":=", 
     RowBox[{"Join", "@@", 
      RowBox[{"Map", "[", 
       RowBox[{"f", ",", "args"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Partition", "-", 
     RowBox[{"Related", " ", "Functions"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Nu]", "[", 
      RowBox[{"A", ":", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "__", "}"}], ".."}], "}"}]}], "]"}], ":=", 
     RowBox[{"Length", "[", "A", "]"}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"number", " ", "of", " ", "blocks"}], " ", "*)"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"num", "[", 
      RowBox[{"A", ":", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "__", "}"}], ".."}], "}"}]}], "]"}], ":=", 
     RowBox[{"Length", "[", 
      RowBox[{"Flatten", "[", "A", "]"}], "]"}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"number", " ", "of", " ", "elements"}], " ", "*)"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", "[", 
      RowBox[{"A", ":", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "__", "}"}], ".."}], "}"}]}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{
        RowBox[{"num", "[", "A", "]"}], "-", 
        RowBox[{"\[Nu]", "[", "A", "]"}]}]], 
      RowBox[{"ProductOver", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Length", "[", "#", "]"}], "-", "1"}], ")"}], "!"}], 
         "&"}], ",", "A"}], "]"}]}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"Moebius", " ", "Mu", " ", "for", " ", "Partitions"}], ",", " ", 
      RowBox[{
       RowBox[{"in", " ", "the", " ", "form", " ", 
        RowBox[{"\[Mu]", "[", "F", "]"}]}], " ", ":=", " ", 
       RowBox[{"\[Mu]", 
        RowBox[{"(", 
         RowBox[{"O", ",", "F"}], ")"}]}]}]}], " ", "*)"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Set", "-", 
     RowBox[{"theoretic", " ", "functions"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Symmetric", " ", "Difference"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SymmetricDifference", "[", 
      RowBox[{"A_", ",", "B_"}], "]"}], ":=", 
     RowBox[{"Complement", "[", 
      RowBox[{
       RowBox[{"Union", "[", 
        RowBox[{"A", ",", "B"}], "]"}], ",", 
       RowBox[{"Intersection", "[", 
        RowBox[{"A", ",", "B"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "Comparison", " ", "function", " ", "for", " ", "the", " ", 
       "\"\<subsets\>\"", " ", "partial", " ", "ordering", 
       "\[IndentingNewLine]", "Returns", " ", "1", " ", "if", " ", "A"}], " ",
       "\[Subset]", " ", "B"}], ";", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], " ", "if", " ", "B"}], " ", "\[Subset]", " ", 
      "A"}], ";", " ", 
     RowBox[{"0", " ", "if", " ", "incomparable"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"IsSubset", "[", 
      RowBox[{"A_", ",", "B_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "X", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"X", "=", 
         RowBox[{"Intersection", "[", 
          RowBox[{"A", ",", "B"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"X", "\[Equal]", "A"}], ",", "1", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"X", "\[Equal]", "B"}], ",", 
            RowBox[{"-", "1"}], ",", "0"}], "]"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "Given", " ", "a", " ", "list", " ", "A", " ", "of", " ", "elements", 
      " ", "and", " ", "a", " ", "partial", " ", "order", " ", "f"}], ",", 
     " ", 
     RowBox[{
      RowBox[{
      "returns", " ", "the", " ", "list", " ", "of", " ", "minimal", " ", 
       "elements", " ", "with", " ", "respect", " ", "to", " ", "f"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Assumes", ":"}], "  ", ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"a", ",", "b"}], "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{"1", " ", "iff", " ", "a"}], " ", "\[LessEqual]", " ", 
        "b"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"a", ",", "b"}], "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], " ", "iff", " ", "a"}], " ", "\[GreaterEqual]", 
        " ", "b"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"a", ",", "b"}], "]"}], " ", "=", " ", 
       RowBox[{"0", " ", "iff", " ", "a"}]}]}], ",", 
     RowBox[{"b", " ", "are", " ", 
      RowBox[{"incomparable", "."}]}]}], "\[IndentingNewLine]", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"MinimalElements", "[", 
      RowBox[{"A_", ",", "f_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"B", ",", "i", ",", "j", ",", "c"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"B", "=", "A"}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{"i", "\[LessEqual]", 
           RowBox[{
            RowBox[{"Length", "[", "B", "]"}], "-", "1"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"j", "=", 
            RowBox[{"i", "+", "1"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"While", "[", 
            RowBox[{
             RowBox[{"j", "\[LessEqual]", 
              RowBox[{"Length", "[", "B", "]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"c", "=", 
               RowBox[{"f", "[", 
                RowBox[{
                 RowBox[{"B", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"B", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"c", "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"j", "++"}], ";", "\[IndentingNewLine]", 
                 RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", " ", 
               RowBox[{"delete", " ", "the", " ", "larger", " ", "entry"}], 
               " ", "*)"}], "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"c", "\[Equal]", "1"}], ",", 
                RowBox[{
                 RowBox[{"B", "=", 
                  RowBox[{"Delete", "[", 
                   RowBox[{"B", ",", "j"}], "]"}]}], ";", 
                 RowBox[{"Continue", "[", "]"}]}], ",", 
                RowBox[{
                 RowBox[{"B", "=", 
                  RowBox[{"Delete", "[", 
                   RowBox[{"B", ",", "i"}], "]"}]}], ";", 
                 RowBox[{"i", "--"}], ";", 
                 RowBox[{"Break", "[", "]"}]}]}], "]"}], ";"}]}], " ", 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"i", "-", 
             RowBox[{
             "th", " ", "entry", " ", "is", " ", "now", " ", "minimal", " ", 
              "and", " ", "larger", " ", "elements", " ", "than", " ", "it", 
              " ", "have", " ", "been", " ", "deleted"}]}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"i", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
        "\[IndentingNewLine]", "B"}]}], "\[IndentingNewLine]", "]"}]}], 
    ";"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.548434124412774*^9, 3.5484341638858337`*^9}, {
   3.548434475323036*^9, 3.548434477946494*^9}, 3.54843553510063*^9, {
   3.54869946666714*^9, 3.54869954612924*^9}, {3.548699619589835*^9, 
   3.548699666825502*^9}, {3.5486998037634897`*^9, 3.54869980521023*^9}, {
   3.548782007631188*^9, 3.548782182998507*^9}, {3.548782215301034*^9, 
   3.548782241112363*^9}, {3.552933250744463*^9, 3.552933315059065*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Chains", " ", "is", " ", "a", " ", "function", " ", "for", " ", 
     "listing", " ", "chains", " ", "of", " ", 
     RowBox[{"subsets", "."}]}], "  ", ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"NOTATION", " ", "FOR", " ", 
     RowBox[{"Chains", ":"}]}], "\[IndentingNewLine]", ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
    "Allowing", " ", "the", " ", "first", " ", "or", " ", "last", " ", "or", 
     " ", "neither", " ", "or", " ", "both", " ", "to", " ", "be", " ", 
     RowBox[{"arbitrary", ":"}]}], "\[IndentingNewLine]", ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chains", "[", "set_", "]"}], " ", ":", " ", 
     RowBox[{
     "gives", " ", "all", " ", "chains", " ", "starting", " ", "at", " ", 
      RowBox[{"{", "}"}], " ", "ending", " ", "at", " ", "set_"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", "True"}], "]"}], " ", ":", " ", 
     RowBox[{
     "gives", " ", "all", " ", "chains", " ", "starting", " ", "at", " ", 
      RowBox[{"{", "}"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", "False"}], "]"}], " ", ":", " ", 
     RowBox[{
     "gives", " ", "all", " ", "chains", " ", "ending", " ", "at", " ", 
      "set_"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", "0"}], "]"}], " ", ":", " ", 
     RowBox[{"gives", " ", "all", " ", "chains"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Specifying", " ", "the", " ", "first", " ", 
     RowBox[{"and", "/", "or"}], " ", "last", " ", 
     RowBox[{"sets", ":"}]}], "\[IndentingNewLine]", ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", 
       RowBox[{"{", 
        RowBox[{"first_", ",", "last_"}], "}"}]}], "]"}], " ", ":", " ", 
     RowBox[{
     "specifies", " ", "first", " ", "and", " ", "last", " ", "sets"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", 
       RowBox[{"{", "first_", "}"}], ",", "True"}], "]"}], " ", ":", " ", 
     RowBox[{"specifies", " ", "first", " ", "set", " ", "only", " ", 
      RowBox[{"(", 
       RowBox[{"last", " ", "arbitrary"}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", 
       RowBox[{"{", "last_", "}"}], ",", "False"}], "]"}], " ", ":", " ", 
     RowBox[{"specifies", " ", "last", " ", "set", " ", "only", " ", 
      RowBox[{"(", 
       RowBox[{"first", " ", "arbitrary"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "*)"}], "\n", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Lists", " ", "all", " ", "chains", " ", "of", " ", "subsets", " ", "of", 
    " ", "set", " ", "for", " ", "which", " ", "the", " ", "first", " ", 
    "set", " ", "is", " ", 
    RowBox[{"{", "}"}], " ", "and", " ", "the", " ", "last", " ", "set", " ", 
    "is", " ", "set_"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", "set_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "chainBuild", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"chainBuild", "[", "curr_", "]"}], ":=", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"Last", "[", "curr", "]"}], "\[Equal]", "set"}], ",", 
           RowBox[{"{", "curr", "}"}], ",", " ", 
           RowBox[{"(*", " ", 
            RowBox[{
            "stop", " ", "if", " ", "chain", " ", "has", " ", "reached", " ", 
             "all", " ", "of", " ", "set"}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"Map", "[", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "choose", " ", "one", " ", "subset", " ", "to", " ", "add", " ", 
              "to", " ", "the", " ", "chain"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"Append", "[", 
               RowBox[{"curr", ",", 
                RowBox[{"Union", "[", 
                 RowBox[{
                  RowBox[{"Last", "[", "curr", "]"}], ",", "#"}], "]"}]}], 
               "]"}], "&"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Drop", "[", " ", 
              RowBox[{"(*", " ", 
               RowBox[{"skip", " ", "the", " ", "empty", " ", "set"}], " ", 
               "*)"}], "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Subsets", "[", 
                RowBox[{"Complement", "[", 
                 RowBox[{"set", ",", 
                  RowBox[{"Last", "[", "curr", "]"}]}], "]"}], "]"}], ",", 
               "\[IndentingNewLine]", "1"}], "]"}]}], "\[IndentingNewLine]", 
            "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Nest", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"ConcatMap", "[", 
            RowBox[{"chainBuild", ",", "#"}], "]"}], "&"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"{", "}"}], "}"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Length", "[", "set", "]"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Lists", " ", "all", " ", "chains", " ", "of", " ", "subsets", " ", "of", 
     " ", "set_", " ", "for", " ", "which", " ", "the", " ", "first", " ", 
     "set", " ", "is", " ", 
     RowBox[{"{", "}"}], " ", "and", " ", "the", " ", "last", " ", "set", " ",
      "is", " ", "arbitrary"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "True"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"{", "}"}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", "True"}], "]"}], ":=", 
     RowBox[{"ConcatMap", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{";;", 
             RowBox[{"-", "2"}]}], "]"}], "]"}]}], "}"}], "&"}], ",", 
       RowBox[{"Chains", "[", "set", "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Lists", " ", "all", " ", "chains", " ", "of", " ", "subsets", " ", "of", 
     " ", "set_", " ", "for", " ", "which", " ", "the", " ", "first", " ", 
     "set", " ", "is", " ", "arbitrary", " ", "and", " ", "the", " ", "last", 
     " ", "set", " ", "is", " ", "set_"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "False"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"{", "}"}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", "False"}], "]"}], ":=", 
     RowBox[{"ConcatMap", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;"}], "]"}], "]"}]}], "}"}], "&"}], ",", 
       RowBox[{"Chains", "[", "set", "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Lists", " ", "all", " ", "chains", " ", "of", " ", "subsets", " ", "of", 
     " ", "set_", " ", 
     RowBox[{"(", 
      RowBox[{
      "both", " ", "the", " ", "first", " ", "and", " ", "last", " ", "set", 
       " ", "can", " ", "be", " ", "anything"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "0"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"{", "}"}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", "0"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"ConcatMap", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#", ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"2", ";;"}], "]"}], "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{";;", 
              RowBox[{"-", "2"}]}], "]"}], "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"2", ";;", 
              RowBox[{"-", "2"}]}], "]"}], "]"}]}], "}"}], "&"}], ",", 
        RowBox[{"Chains", "[", "set", "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{";;", 
        RowBox[{"-", "2"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Lists", " ", "all", " ", "chains", " ", "of", " ", "subsets", " ", "of", 
     " ", "set_", " ", "with", " ", "specified", " ", "first", " ", "and", 
     " ", "last", " ", "subsets"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", 
       RowBox[{"{", 
        RowBox[{"first_", ",", "last_"}], "}"}]}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Map", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Union", "[", 
            RowBox[{"#", ",", "first"}], "]"}], "&"}], ",", "#"}], "]"}], 
        "&"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Chains", "[", 
        RowBox[{"Complement", "[", 
         RowBox[{"last", ",", "first"}], "]"}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Lists", " ", "all", " ", "chains", " ", "of", " ", "subsets", " ", "of", 
     " ", "set_", " ", "with", " ", "specified", " ", "first", " ", "set", 
     " ", "and", " ", "arbitrary", " ", "last", " ", "subset"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", 
       RowBox[{"{", "first_", "}"}], ",", "True"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Map", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Union", "[", 
            RowBox[{"#", ",", "first"}], "]"}], "&"}], ",", "#"}], "]"}], 
        "&"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Chains", "[", 
        RowBox[{
         RowBox[{"Complement", "[", 
          RowBox[{"set", ",", "first"}], "]"}], ",", "True"}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Lists", " ", "all", " ", "chains", " ", "of", " ", "subsets", " ", "of", 
     " ", "set_", " ", "with", " ", "arbitrary", " ", "first", " ", "set", 
     " ", "and", " ", "specified", " ", "last", " ", "subset"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"set_", ",", 
       RowBox[{"{", "last_", "}"}], ",", "False"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Map", "[", "\[IndentingNewLine]", 
      RowBox[{"Reverse", ",", "\[IndentingNewLine]", 
       RowBox[{"Map", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Complement", "[", 
              RowBox[{"set", ",", "#"}], "]"}], "&"}], ",", "#"}], "]"}], 
          "&"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Chains", "[", 
          RowBox[{"set", ",", 
           RowBox[{"{", 
            RowBox[{"Complement", "[", 
             RowBox[{"set", ",", "last"}], "]"}], "}"}], ",", "True"}], 
          "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    ";"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.549050735176704*^9, 3.5490509253049917`*^9}, {
   3.549051881122849*^9, 3.549051898439601*^9}, {3.549161350504529*^9, 
   3.5491614897202587`*^9}, {3.549161537802732*^9, 3.549161544549074*^9}, {
   3.549161581590646*^9, 3.5491616455626993`*^9}, {3.5491618389511023`*^9, 
   3.5491618790057573`*^9}, {3.550091120854064*^9, 3.550091154040449*^9}, {
   3.5501256157077017`*^9, 3.550125695534174*^9}, 3.550125975970593*^9, 
   3.550251684038349*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
   "Returns", " ", "a", " ", "list", " ", "of", " ", "all", " ", "chains", 
    " ", "in", " ", "P", 
    RowBox[{"(", "n", ")"}], " ", "such", " ", "that", " ", "the", " ", 
    "smallest", " ", "set", " ", "contains", " ", "1", " ", "and", " ", "the",
     " ", "largest", " ", "set", " ", "equals", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", ".."}], "n"}], "}"}]}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Chains", "[", 
      RowBox[{"n_", ",", "\"\<Has1\>\""}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"set", ",", "chainBuild"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"set", "=", 
         RowBox[{"Range", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"chainBuild", "[", "curr_", "]"}], ":=", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Last", "[", "curr", "]"}], "\[Equal]", "set"}], ",", 
           RowBox[{"{", "curr", "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Map", "[", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "choose", " ", "what", " ", "to", " ", "add", " ", "to", " ", 
              "the", " ", "chain"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"Append", "[", 
               RowBox[{"curr", ",", 
                RowBox[{"Union", "[", 
                 RowBox[{
                  RowBox[{"Last", "[", "curr", "]"}], ",", "#"}], "]"}]}], 
               "]"}], "&"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Drop", "[", " ", 
              RowBox[{"(*", " ", 
               RowBox[{"skip", " ", "the", " ", "empty", " ", "set"}], " ", 
               "*)"}], "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Subsets", "[", 
                RowBox[{"Complement", "[", 
                 RowBox[{"set", ",", 
                  RowBox[{"Last", "[", "curr", "]"}]}], "]"}], "]"}], ",", 
               "\[IndentingNewLine]", "1"}], "]"}]}], "\[IndentingNewLine]", 
            "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Nest", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"ConcatMap", "[", 
            RowBox[{"chainBuild", ",", "#"}], "]"}], "&"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Prepend", "[", 
               RowBox[{"#", ",", "1"}], "]"}], "}"}], "&"}], ",", 
            RowBox[{"Subsets", "[", 
             RowBox[{"Range", "[", 
              RowBox[{"2", ",", "n"}], "]"}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "n"}], "]"}]}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\n"}]}]], "Input",
 CellChangeTimes->{{3.5501257047538013`*^9, 3.5501257200689707`*^9}, {
  3.550251696024349*^9, 3.550251696504983*^9}}]
},
WindowSize->{740, 569},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 10561, 271, 908, "Input",
 InitializationCell->True],
Cell[11121, 293, 12947, 325, 1258, "Input",
 InitializationCell->True],
Cell[24071, 620, 3178, 76, 328, "Input"]
}
]
*)

(* End of internal cache information *)
